#!/bin/bash

function print_kernel_message()
{
    if [ -e /dev/kmsg ]
    then
        echo $1 > /dev/kmsg
    fi
}

function read_dts()
{
    DTS_PATH=/sys/firmware/devicetree/base/wifi_bt_power_on
    FILENAME=${DTS_PATH}/$1
    input=$(xxd $FILENAME)
    lastName=${input:15:4}
    num=$((16#$lastName))
	echo $num
}

function gpio_power()
{
	print_kernel_message "gpio_power $*"
	GPIO_PATH=/sys/class/gpio/gpio$1
	if [ -d ${GPIO_PATH} ]; then
		rm -rf ${GPIO_PATH}
	fi
	echo $1 > /sys/class/gpio/export
	echo $2 > ${GPIO_PATH}/value
	print_kernel_message "${GPIO_PATH}/value $(cat ${GPIO_PATH}/value)"
	sleep 0.1
	if [ $2 == 0 ]; then
		sleep 0.1
	fi
	echo $1 > /sys/class/gpio/unexport
}

function close_service()
{
	print_kernel_message "close_service $*"
	service_pid=`ps -ef | grep ${1} | grep -v grep | awk '{printf $2}'`
	print_kernel_message "service_pid ${service_pid}"
	kill -9 ${service_pid}
	print_kernel_message "${1} kill succ"
	systemctl stop ${2}
}

function main()
{
	print_kernel_message "main $*"
	_wifi_power_on_gpio=$(read_dts wifi_power_on_gpio)
	print_kernel_message "wifi_power_on_gpio ${_wifi_power_on_gpio}"
	_wifi_wl_en_gpio=$(read_dts wifi_wl_en_gpio)
	print_kernel_message "wifi_wl_en_gpio ${_wifi_wl_en_gpio}"
	_wifi_bt_en_gpio=$(read_dts wifi_bt_en_gpio)
	print_kernel_message "wifi_bt_en_gpio ${_wifi_bt_en_gpio}"
	_s3_bt_wakeup_support=$(read_dts s3_bt_wakeup_support)
	print_kernel_message "s3_bt_wakeup_support ${_s3_bt_wakeup_support}"
	_s3_wl_wakeup_support=$(read_dts s3_wl_wakeup_support)	
	print_kernel_message "_s3_wl_wakeup_support ${_s3_wl_wakeup_support}"
	if [ "${1}" == "pre" ]; then
		if [ ${2} == "hibernate" ]; then
			close_service rtk_hciattach rtkbt_hciattach.service
			#gpio_power ${_wifi_bt_en_gpio} 0
		fi
	fi
	
	if [ "${1}" == "post" ]; then
		if [ "${2}" == "hibernate" ]; then
			gpio_power ${_wifi_bt_en_gpio} 0
			gpio_power ${_wifi_bt_en_gpio} 1
			systemctl start rtkbt_hciattach.service			
		fi
	fi	
}

print_kernel_message "$0 $*"
main $@

