#!/bin/bash

function print_kernel_message()
{
    if [ -e /dev/kmsg ]
    then
        echo $1 > /dev/kmsg
    fi
}

function insmod_kernel_module()
{
    module_file_path=$1
    if [ -e $module_file_path ]
    then
        insmod $module_file_path
        if [ $? -eq 0 ]
        then
            print_kernel_message "kernel module $module_file_path insmod succ"
        else
            print_kernel_message "kernel module $module_file_path insmod failed!ret=$?"
            return 1
        fi
    else
        print_kernel_message "module:$module_file_path not exist"
        return 1
    fi
    return 0
}

function insmod_wifi_modules()
{
    insmod_kernel_module /vendor/realtek/$1
    if [ $? -ne 0 ]
    then
        return 1;
    fi

    print_kernel_message "insmod $1 succ"
    return 0
}

function insmod_detect_modules()                                 
{                                                                
    #insmod_kernel_module /vendor/realtek/sdio_wifi_detect.ko            
    modprobe sdio_wifi_detect
    if [ $? -ne 0 ]                                              
    then                                                      
        return 1;                                             
    fi                                                        
 
    print_kernel_message "insmod sdio_wifi_detect.ko succ"                        
    return 0                                                                    
}

function run_rkt_hciattch()
{
    if [ ! -e /vendor/realtek/rtk_hciattach ]; then
        print_kernel_message " /vendor/realtek no rtk_hciattach program....."
        return 1
    fi

    cd /vendor/realtek
    ./rtk_hciattach -n -s 115200 ttyAMA3 rtk_h5 &
    if [ $? -ne 0 ]
    then
        cd -
        return 1;
    fi
    cd -
    print_kernel_message "rtk hciattach  succ"
    return 0
}

load_drivers()
{
    local sdio_proc="/sys/bus/sdio/devices"
    local sdio_device=""
    local wifi_device=""    
    kernel_name_path=`uname -r`
    print_kernel_message "wifi wl_en bt_en enable..."
    insmod_detect_modules

    sdio_device=$(ls ${sdio_proc})
    if [[ $sdio_device == "" ]]; then
        print_kernel_message "borad no wifi device."
        return 0
    fi
    wifi_device=$(cat ${sdio_proc}/${sdio_device}/device)
    if [[ $wifi_device == "0xb822" ]]; then
        print_kernel_message "insmod rtl8822bs wifi ko..."
        #insmod_wifi_modules "rtl8822bs.ko"
        modprobe rtl8822bs
	run_rkt_hciattch
    fi
    if [[ $wifi_device == "0xc822" ]]; then
        print_kernel_message "insmod rtl8822cs wifi ko..."
	#insmod_wifi_modules "rtl8822cs.ko"
	modprobe rtl8822cs
        run_rkt_hciattch
    fi
    if [[ $wifi_device == "0xa822" ]]; then
        echo "insmod rtl8822cs_ve wifi ko..."
        modprobe rtl88x2es
	run_rkt_hciattch
	#$insmod_wifi_path=/lib/modules/$kernel_name_path/kernel/drivers/net/wireless/realtek/rtl8822cs_ve/88x2es.ko
        #$rmmod_wifi_module=88x2es
    fi
   if [[ $wifi_device == "0x5349" ]]; then
        echo "insmod 1105 wifi ko..."
	echo "$kernel_name_path"
	modprobe cfg80211
	insmod_kernel_module  "/lib/modules/$kernel_name_path/kernel/drivers/plat_1105.ko"
	insmod_kernel_module  "/lib/modules/$kernel_name_path/kernel/drivers/wifi_1105.ko"
	mkdir -p /lib/vendor && echo -n wlan0 >/lib/vendor/interface
    fi

   if [[ $wifi_device == "0xb852" ]]; then
        print_kernel_message "insmod rtl8852bs wifi ko..."
	modprobe 8852bs
	run_rkt_hciattch
   fi
    return $?
}

function main_user()
{
    load_drivers

}
#--------------------main-----------------
main_user


